@@ -2,13 +2,13 @@ pub mod base;
 
 #[allow(dead_code, unused_imports)]
 #[path = "./events_generated.rs"]
-mod events_generated;
+pub mod events_generated;
 #[allow(dead_code, unused_imports)]
 #[path = "./frame_generated.rs"]
-mod frame_generated;
+pub mod frame_generated;
 #[allow(dead_code, unused_imports)]
 #[path = "./imus_generated.rs"]
-mod imus_generated;
+pub mod imus_generated;
 #[allow(dead_code, unused_imports)]
 #[path = "./triggers_generated.rs"]
-mod triggers_generated;
+pub mod triggers_generated;
